@@ -1,15 +1,20 @@
-#include <vorbis/codec.h>
 #include <pyogg/pyogg.h>
 
 #include "general.h"
 #include "_oggmodule.h"
 
 #include "pyoggstreamstate.h"
+#include "pyoggsyncstate.h"
 #include "pyoggpacket.h"
+#include "pyoggpackbuff.h"
 
 static PyMethodDef Ogg_methods[] = {
   {"OggStreamState", py_ogg_stream_state_new, 
    METH_VARARGS, py_ogg_stream_state_doc},
+  {"OggPackBuff", py_oggpack_buffer_new,
+   METH_VARARGS, py_oggpack_buffer_doc},
+  {"OggSyncState", py_ogg_sync_state_new,
+   METH_VARARGS, py_ogg_sync_state_doc},
   {NULL, NULL}
 };
 
@@ -22,6 +27,7 @@ static ogg_module_info mi = {
   &py_ogg_stream_state_type,
   NULL,                          /* Will be Py_OggError */
   py_ogg_packet_from_packet,
+  arg_to_int64,
 };
 
 void
